==============
feedaggregator
==============

An Django 1.8 app to aggregate RSS and Atom feeds(planet)

Features
========

* Python 2/3 compatible
* Import/export OPML feeds
* Browse posts by Feed, Author or Tag
* Bootstrap templates
* RSS and Atom feeds
* Sitemaps
* Show word clouds like it's 2004
* Multiple templatetags to adapt the site
* SEO metatags
* Customizable via settings.py

TODO
====

* Upload demo
* Improve tests and docs

Documentation
=============

Online documentation is available at http://django-feedaggregator.readthedocs.org/

License
=======

MIT license
